Index: /CKEditor/branches/features/bbcode/_source/core/dom/element.js
===================================================================
--- /CKEditor/branches/features/bbcode/_source/core/dom/element.js	(revision 6701)
+++ /CKEditor/branches/features/bbcode/_source/core/dom/element.js	(revision 6702)
@@ -488,5 +488,5 @@
 				function( propertyName )
 				{
-					return this.$.currentStyle[ CKEDITOR.tools.cssStyleToDomStyle( propertyName ) ];
+					return this.$.currentStyle && this.$.currentStyle[ CKEDITOR.tools.cssStyleToDomStyle( propertyName ) ];
 				}
 			:
Index: /CKEditor/branches/features/bbcode/_source/plugins/bidi/plugin.js
===================================================================
--- /CKEditor/branches/features/bbcode/_source/plugins/bidi/plugin.js	(revision 6701)
+++ /CKEditor/branches/features/bbcode/_source/plugins/bidi/plugin.js	(revision 6702)
@@ -262,5 +262,5 @@
 	});
 
 	// If the element direction changed, we need to switch the margins of
 	// the element and all its children, so it will get really reflected
 	// like a mirror. (#5910)
@@ -273,5 +273,5 @@
 		return function( name, val )
 		{
-			if ( !this.getDocument().equals( CKEDITOR.document ) )
+			if ( !this.getDocument().equals( CKEDITOR.document ) && this.isBlockBoundary() )
 			{
 				var orgDir, dir;
@@ -262,5 +262,5 @@
 	});
 
-	// If the element direction changed, we need to switch the margins of
+	// If a block direction changed, we need to switch the margins of
 	// the element and all its children, so it will get really reflected
 	// like a mirror. (#5910)
